@@ -6,8 +6,8 @@ set.seed(3141)
 dml_data = make_plr_CCDDHNR2018(n_obs = 100)
 dml_cluster_data = make_pliv_multiway_cluster_CKMS2021(N = 10, M = 10, dim_X = 5)
 
-ml_g = ml_m = ml_r = "regr.rpart"
-dml_plr = DoubleMLPLR$new(dml_data, ml_g, ml_m, n_folds = 2)
+ml_l = ml_g = ml_m = ml_r = "regr.rpart"
+dml_plr = DoubleMLPLR$new(dml_data, ml_l, ml_m, n_folds = 2)
 dml_pliv = DoubleMLPLIV$new(dml_cluster_data, ml_g, ml_m, ml_r, n_folds = 2)
 dml_plr$fit()
 dml_pliv$fit()
